Trait delay_queue::Delayed
[−]
[src]
pub trait Delayed {
fn delayed_until(&self) -> Instant;
}A value that is delayed until some Instant.
The DelayQueue only accepts values that implement this trait.
In most situations you do not need to implement this trait yourself. You can use the helper
struct Delay.
Required Methods
fn delayed_until(&self) -> Instant
Returns the Instant until which this value is delayed.
Implementors
impl<T> Delayed for Delay<T>